
**********************************************************************************
* US Housing Wealth Effects Project, Carroll, Otsuka and Slacalek
**********************************************************************************

clear
#delimit;

set more off;
global basePath "\\\\CCARROLL\shared\COS-WealthEffects20080717\empirical";
global basePath "C:\Jirka\Research\usWealth\cosWealthEffects\empirical";
global dataPath $basePath\data;  
global logPath $basePath\stata;
global docPath $basePath\docs\tabs;

cd $logPath;
capture log close;
log using $logPath\ushweRobust.log, replace;

global consIndex "1";		* 1: total PCE [default], 2: total PCE ex housing services, 3: NDS;
global startReg "1960q1";	* start of the sample;
global endReg "2007q4";		* end of the sample;
global startRegW "1960q1";	* start of the sample for wealth regressions "1985q1";
global endRegW "2007q4";		* end of the sample for wealth regressions;
global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

global nwLags "4";			* # of lags for Newey-West std errors;
global nwLagsW "8";			* # of lags for Newey-West std errors in wealth regressions;

global normVar "tcons";		* tcons ydisp;

log off;
use $dataPath\usdata.dta;
gen t =  q(1947q1)+_n-1;
format t %tq;
tsset t;

do transformData;
log on;

* Model 1: Alternative Instruments;
**********************************************************************************;
global controlVars " L.dsp500 L.dunp L.dydisp L.irSpread";
global ivsetWPlus "L(2).dwdel L(2).dsp500 L(2).dunp L(2).dydisp L(2).irSpread";
global ivsetWSandNPlus "L(2).dwstdel L(2).dsp500 L(2).dunp L(2).dydisp L(2).irSpread";

ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m1chi=_b[L.cdel];
sca m1seChi=_se[L.cdel];
gen dwdelm1  = (D.wealth+m1chi*LD.wealth +(m1chi^2)*L2D.wealth +(m1chi^3)*L3D.wealth)/L4.$normVar;

reg cdel L.dwdelm1 $controlVars if tin($startRegW,$endRegW);
sca m1rbar=e(r2_a);

newey cdel L.dwdelm1 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m1bSR=_b[L.dwdelm1];
sca m1seBsr=_se[L.dwdelm1];
sca m1bLR=m1bSR/(m1chi*(1-m1chi));

* Model 2;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m2chi=_b[L.cdel];
sca m2seChi=_se[L.cdel];

gen dwstdelm2  = (D.wthstock+m2chi*LD.wthstock +(m2chi^2)*L2D.wthstock +(m2chi^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdelm2  = (D.wthnonstock+m2chi*LD.wthnonstock +(m2chi^2)*L2D.wthnonstock + (m2chi^3)*L3D.wthnonstock)/L4.$normVar;

reg cdel L.dwstdelm2 L.dwnstdelm2 $controlVars if tin($startRegW,$endRegW);
sca m2rbar=e(r2_a);

newey cdel L.dwstdelm2 L.dwnstdelm2 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m2bfSR=_b[L.dwstdelm2];
sca m2seBfSR=_se[L.dwstdelm2];
sca m2bhSR=_b[L.dwnstdelm2];
sca m2seBhSR=_se[L.dwnstdelm2];
sca m2bfLR=m2bfSR/(m2chi*(1-m2chi));
sca m2bhLR=m2bhSR/(m2chi*(1-m2chi));

test L.dwstdelm2 = L.dwnstdelm2;
sca m2pval=r(p);

* Model 3: Lagged Instruments;
**********************************************************************************;
global controlVars " L.dsp500 L.dunp L.dydisp L.irSpread";
global ivsetWPlus "L(3/4).dwdel L(3/4).dsp500 L(3/4).dunp L(3/4).dydisp L(3/4).irSpread";
global ivsetWSandNPlus "L(3/4).dwstdel L(3/4).dwnstdel L(3/4).dsp500 L(3/4).dunp L(3/4).dydisp L(3/4).irSpread";

ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m3chi=_b[L.cdel];
sca m3seChi=_se[L.cdel];
gen dwdelm3  = (D.wealth+m3chi*LD.wealth +(m3chi^2)*L2D.wealth +(m3chi^3)*L3D.wealth)/L4.$normVar;

reg cdel L.dwdelm3 $controlVars if tin($startRegW,$endRegW);
sca m3rbar=e(r2_a);

newey cdel L.dwdelm3 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m3bSR=_b[L.dwdelm3];
sca m3seBsr=_se[L.dwdelm3];
sca m3bLR=m3bSR/(m3chi*(1-m3chi));

* Model 4;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m4chi=_b[L.cdel];
sca m4seChi=_se[L.cdel];

gen dwstdelm4  = (D.wthstock+m4chi*LD.wthstock +(m4chi^2)*L2D.wthstock +(m4chi^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdelm4  = (D.wthnonstock+m4chi*LD.wthnonstock +(m4chi^2)*L2D.wthnonstock + (m4chi^3)*L3D.wthnonstock)/L4.$normVar;

reg cdel L.dwstdelm4 L.dwnstdelm4 $controlVars if tin($startRegW,$endRegW);
sca m4rbar=e(r2_a);

newey cdel L.dwstdelm4 L.dwnstdelm4 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m4bfSR=_b[L.dwstdelm4];
sca m4seBfSR=_se[L.dwstdelm4];
sca m4bhSR=_b[L.dwnstdelm4];
sca m4seBhSR=_se[L.dwnstdelm4];
sca m4bfLR=m4bfSR/(m4chi*(1-m4chi));
sca m4bhLR=m4bhSR/(m4chi*(1-m4chi));

test L.dwstdelm4 = L.dwnstdelm4;
sca m4pval=r(p);

* Model 5: Iterative Procedure;
**********************************************************************************;
global controlVars "L.MUExp L.fedfunds";
global ivsetWPlus "L(2).dwdel L(2).MUExp L(2).fedfunds";
global ivsetWSandNPlus "L(2).dwstdel L(2).dwnstdel L(2).MUExp L(2).fedfunds";

ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m5chi=_b[L.cdel];
sca m5seChi=_se[L.cdel];
gen dwdelm5  = (D.wealth+m5chi*LD.wealth +(m5chi^2)*L2D.wealth +(m5chi^3)*L3D.wealth)/L4.$normVar;

global ivsetWPlus "L(2).dwdelm5 L(2).MUExp L(2).fedfunds";
ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m5chi=_b[L.cdel];
sca m5seChi=_se[L.cdel];
replace dwdelm5  = (D.wealth+m5chi*LD.wealth +(m5chi^2)*L2D.wealth +(m5chi^3)*L3D.wealth)/L4.$normVar;

reg cdel L.dwdelm5 $controlVars if tin($startRegW,$endRegW);
sca m5rbar=e(r2_a);

newey cdel L.dwdelm5 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m5bSR=_b[L.dwdelm5];
sca m5seBsr=_se[L.dwdelm5];
sca m5bLR=m5bSR/(m5chi*(1-m5chi));

* Model 6;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m6chi=_b[L.cdel];
sca m6seChi=_se[L.cdel];

gen dwstdelm6  = (D.wthstock+m6chi*LD.wthstock +(m6chi^2)*L2D.wthstock +(m6chi^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdelm6  = (D.wthnonstock+m6chi*LD.wthnonstock +(m6chi^2)*L2D.wthnonstock + (m6chi^3)*L3D.wthnonstock)/L4.$normVar;

global ivsetWSandNPlus "L(2).dwstdelm6 L(2).dwnstdelm6 L(2).MUExp L(2).fedfunds";
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m6chi=_b[L.cdel];
sca m6seChi=_se[L.cdel];

replace dwstdelm6  = (D.wthstock+m6chi*LD.wthstock +(m6chi^2)*L2D.wthstock +(m6chi^3)*L3D.wthstock)/L4.$normVar;
replace dwnstdelm6  = (D.wthnonstock+m6chi*LD.wthnonstock +(m6chi^2)*L2D.wthnonstock + (m6chi^3)*L3D.wthnonstock)/L4.$normVar;

reg cdel L.dwstdelm6 L.dwnstdelm6 $controlVars if tin($startRegW,$endRegW);
sca m6rbar=e(r2_a);

newey cdel L.dwstdelm6 L.dwnstdelm6 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m6bfSR=_b[L.dwstdelm6];
sca m6seBfSR=_se[L.dwstdelm6];
sca m6bhSR=_b[L.dwnstdelm6];
sca m6seBhSR=_se[L.dwnstdelm6];
sca m6bfLR=m6bfSR/(m6chi*(1-m6chi));
sca m6bhLR=m6bhSR/(m6chi*(1-m6chi));

test L.dwstdelm6 = L.dwnstdelm6;
sca m6pval=r(p);


* Model 7: Iterative Procedure;
**********************************************************************************;
global controlVars "L.MUExp L.fedfunds";
global ivsetWPlus "L(2).dwdel L(2).MUExp L(2).fedfunds";
global ivsetWSandNPlus "L(2).dwstdel L(2).dwnstdel L(2).MUExp L(2).fedfunds";

ivreg2 cdel (L.cdel=$ivsetWPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m7chi=_b[L.cdel];
sca m7seChi=_se[L.cdel];
gen dwdelm7  = (D.wealth+m7chi*LD.wealth +(m7chi^2)*L2D.wealth +(m7chi^3)*L3D.wealth)/L4.$normVar;

reg cdel L.dwdelm7 $controlVars if tin($startRegW,$endRegW);
sca m7rbar=e(r2_a);

newey cdel L.dwdelm7 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m7bSR=_b[L.dwdelm7];
sca m7seBsr=_se[L.dwdelm7];
sca m7bLR=m7bSR/(m7chi*(1-m7chi));

* Model 8;
**********************************************************************************;
ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m8chi=_b[L.cdel];
sca m8seChi=_se[L.cdel];

gen dwstdelm8  = (D.wthstock+m8chi*LD.wthstock +(m8chi^2)*L2D.wthstock +(m8chi^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdelm8  = (D.wthnonstock+m8chi*LD.wthnonstock +(m8chi^2)*L2D.wthnonstock + (m8chi^3)*L3D.wthnonstock)/L4.$normVar;

reg cdel L.dwstdelm8 L.dwnstdelm8 $controlVars if tin($startRegW,$endRegW);
sca m8rbar=e(r2_a);

newey cdel L.dwstdelm8 L.dwnstdelm8 $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m8bfSR=_b[L.dwstdelm8];
sca m8seBfSR=_se[L.dwstdelm8];
sca m8bhSR=_b[L.dwnstdelm8];
sca m8seBhSR=_se[L.dwnstdelm8];
sca m8bfLR=m8bfSR/(m8chi*(1-m8chi));
sca m8bhLR=m8bhSR/(m8chi*(1-m8chi));

test L.dwstdelm8 = L.dwnstdelm8;
sca m8pval=r(p);

* Model 9: Real-estate (housing) wealth vs non-stock wealth;
**********************************************************************************;
replace dwstdel=dwredel;
replace dwnstdel=dwnredel;

ivreg2 cdel (L.cdel=$ivsetWSandNPlus) if tin($startReg,$endReg), robust bw($nwLags) ffirst;
sca m9chi=_b[L.cdel];
sca m9seChi=_se[L.cdel];

replace wthnonstock=netREhh_real;
replace wthstock=netNREhh_real;

gen dwstdelm9  = (D.wthstock+m9chi*LD.wthstock +(m9chi^2)*L2D.wthstock +(m9chi^3)*L3D.wthstock)/L4.$normVar;
gen dwnstdelm9  = (D.wthnonstock+m9chi*LD.wthnonstock +(m9chi^2)*L2D.wthnonstock + (m9chi^3)*L3D.wthnonstock)/L4.$normVar;

reg cdel L.dwstdelm9 L.dwnstdelm9 if tin($startRegW,$endRegW);
sca m9rbar=e(r2_a);

newey cdel L.dwstdelm9 L.dwnstdelm9  $controlVars if tin($startRegW,$endRegW), lag($nwLagsW);
sca m9bfSR=_b[L.dwstdelm9];
sca m9seBfSR=_se[L.dwstdelm9];
sca m9bhSR=_b[L.dwnstdelm9];
sca m9seBhSR=_se[L.dwnstdelm9];
sca m9bfLR=m9bfSR/(m9chi*(1-m9chi));
sca m9bhLR=m9bhSR/(m9chi*(1-m9chi));

test L.dwstdelm9 = L.dwnstdelm9;
sca m9pval=r(p);


* Print Tables;
**********************************************************************************;
do writeTabRobust;

disp  "Non Real Estate MPC" m9bfLR;
disp  "Real Estate MPC" m9bhLR;

**********************************************************************************;
log close;	
