
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Carroll, Otsuka, Slacalek: How Large Is the Housing Wealth Effect?
%
% This MATLAB program is called by ....m and prints out LaTeX code
% for Table with summary results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% necessary to input two matrices: tableValues (13x5) matrix of values to
% be printed out in the table and tStats (13x4) matrix of t stats
% corresponding to the first 4 columns of tableVars. 

filePath=[basePath,'\tables\paper\tCOSallPers.tex'];
fid=fopen(filePath,'w');

fprintf(fid, '\\begin{table} \\small \n \\caption{Estimates of the Wealth Effect in Simulated Data---The COS Method \\label{tWEcos}} \n');
fprintf(fid, '\\begin{minipage}{\\textwidth} \n');
fprintf(fid, '\\begin{center} \n');
fprintf(fid, '$ \n \\Delta \\CLev_t=\\chi\\mathbb{E}_{t-2}\\Delta \\CLev_{t-1}+\\alpha\\Delta \\BLev_{t-1}+\\varepsilon_t \n $\\\\[3mm] \n');
fprintf(fid, '\\begin{tabular}{@{}d{4}d{7}d{4}d{7}d{4}d{7}d{4}d{7}@{}}');
fprintf(fid, '\n \\toprule \n ');
fprintf(fid, ' & & \\multicolumn{6}{c}{Estimated }  \\\\ \n');
fprintf(fid, '\\cmidrule{3-8} \n');
fprintf(fid, '\\multicolumn{2}{c}{True } & \\multicolumn{2}{c}{$n='); fprintf(fid,'%5.0f',nPersAll(1)); 
fprintf(fid,'$} & \\multicolumn{2}{c}{$n='); fprintf(fid,'%5.0f',nPersAll(2)); 
fprintf(fid,'$} & \\multicolumn{2}{c}{$n='); fprintf(fid,'%5.0f',nPersAll(3)); 
fprintf(fid,'$}  \\\\ \n');
fprintf(fid, '\\cmidrule(r){1-2} \\cmidrule(r){3-4} \\cmidrule(r){5-6} \\cmidrule(r){7-8} \n');
fprintf(fid, '\\multicolumn{1}{c}{$\\chi$} & \\multicolumn{1}{c}{$\\big(\\Rfree-(\\Rfree\\beta)^{1/\\rho}\\big)/\\Rfree$} & \\multicolumn{1}{c}{$\\chi$} & \\multicolumn{1}{c}{$\\alpha/\\chi(1-\\chi)$} & ');
fprintf(fid, ' \\multicolumn{1}{c}{$\\chi$} & \\multicolumn{1}{c}{$\\alpha/\\chi(1-\\chi)$} &\\multicolumn{1}{c}{$\\chi$} & \\multicolumn{1}{c}{$\\alpha/\\chi(1-\\chi)$}  \\\\ '); 
fprintf(fid, '\\midrule \n');
fprintf(fid,'%5.2f',(1-PiFrac)); fprintf(fid,' & & '); fprintf(fid,'%5.3f',chiOLSall(1)); fprintf(fid,' &  & ');
fprintf(fid,'%5.3f',chiOLSall(2)); fprintf(fid,' & & '); fprintf(fid,'%5.3f',chiOLSall(3)); fprintf(fid,' &  \\\\ \n');

fprintf(fid,'%5.2f',(1-PiFrac)); fprintf(fid,' & '); fprintf(fid,'%5.4f',alphaTrue); fprintf(fid,' & '); 
fprintf(fid,'%5.3f',chiIVjointAll(1)); fprintf(fid,' & '); fprintf(fid,'%5.4f',alphaJointAll(1)/(chiIVjointAll(1)*(1-chiIVjointAll(1)))); fprintf(fid,' & ');  
fprintf(fid,'%5.3f',chiIVjointAll(2)); fprintf(fid,' & '); fprintf(fid,'%5.4f',alphaJointAll(2)/(chiIVjointAll(2)*(1-chiIVjointAll(2)))); fprintf(fid,' & ');  
fprintf(fid,'%5.3f',chiIVjointAll(3)); fprintf(fid,' & '); fprintf(fid,'%5.4f',alphaJointAll(3)/(chiIVjointAll(3)*(1-chiIVjointAll(3)))); 
fprintf(fid,' \\\\ \n  ');

% Here is the rest
fprintf(fid,'\\bottomrule \n \\end{tabular} \n \\end{center} \n {\\sl Notes:}  Calibration: $\\rho=');
fprintf(fid,'%2.0f',rho);
fprintf(fid,'$, $\\beta=');    
fprintf(fid,'%4.2f',beta);
fprintf(fid,'$, $\\Rfree=\\WGro^\\rho/\\beta$, $\\Pi=');    
fprintf(fid,'%4.2f',PiFrac);
fprintf(fid,'$, $\\underline{\\WGro}=');    
G4=G^4; G1_4=G1^4;
fprintf(fid,'%4.3f',G4);
fprintf(fid,'^{1/4}$, $\\WGro=');    
fprintf(fid,'%4.3f',G1_4);
fprintf(fid,['^{1/4}$, wealth shock ${}=1$. $\\Delta \\CLev_{t-1}$ instrumented with $\\Delta \\CLev_{t-2}$. \\\\ \n \\showEstTime{Estimated:' datestr(now) ' \\\\ }  \n']);
fprintf(fid,'\\end{minipage} \n');
fprintf(fid,'\\end{table} \n');
fclose(fid);
